summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/widgets/tqlistview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/widgets/tqlistview.cpp')
-rw-r--r--tqtinterface/qt4/src/widgets/tqlistview.cpp58
1 files changed, 29 insertions, 29 deletions
diff --git a/tqtinterface/qt4/src/widgets/tqlistview.cpp b/tqtinterface/qt4/src/widgets/tqlistview.cpp
index 46060c8..506ec60 100644
--- a/tqtinterface/qt4/src/widgets/tqlistview.cpp
+++ b/tqtinterface/qt4/src/widgets/tqlistview.cpp
@@ -403,7 +403,7 @@ static TQString qEllipsisText( const TQString &org, const TQFontMetrics &fm, int
you can get a pointer to any TQListViewItem in a TQListView using
TQListView::selectedItem(), TQListView::currentItem(),
TQListView::firstChild(), TQListView::lastItem() and
- TQListView::tqfindItem().
+ TQListView::findItem().
If you call \c delete on a list view item, it will be deleted as
expected, and as usual for \l{TQObject}s, if it has any child items
@@ -1115,7 +1115,7 @@ bool TQListViewItem::acceptDrop( const TQMimeSource * ) const
/*!
This function is called when something was dropped on the item. \a e
- tqcontains all the information about the drop.
+ contains all the information about the drop.
The default implementation does nothing, subclasses may need to
reimplement this function.
@@ -1611,7 +1611,7 @@ void TQListViewItem::setup()
if ( mlenabled ) {
h = ph;
for ( int c = 0; c < lv->columns(); ++c ) {
- int lines = text( c ).tqcontains( TQChar('\n') ) + 1;
+ int lines = text( c ).contains( TQChar('\n') ) + 1;
int tmph = lv->d->fontMetricsHeight
+ lv->fontMetrics().lineSpacing() * ( lines - 1 );
h = TQMAX( h, tmph );
@@ -1884,9 +1884,9 @@ void TQListViewItem::setText( int column, const TQString &text )
int newLc = 0;
if ( mlenabled ) {
if ( !l->text.isEmpty() )
- oldLc = l->text.tqcontains( TQChar( '\n' ) ) + 1;
+ oldLc = l->text.contains( TQChar( '\n' ) ) + 1;
if ( !text.isEmpty() )
- newLc = text.tqcontains( TQChar( '\n' ) ) + 1;
+ newLc = text.contains( TQChar( '\n' ) ) + 1;
}
l->dirty = TRUE;
@@ -2860,7 +2860,7 @@ void TQListView::drawContentsOffset( TQPainter * p, int ox, int oy,
while( (i = (TQListViewItem *)(it.currentKey())) != 0 ) {
++it;
TQRect ir = tqitemRect( i ).intersect( viewport()->rect() );
- if ( ir.isEmpty() || br.tqcontains( ir ) )
+ if ( ir.isEmpty() || br.contains( ir ) )
// we're painting this one, or it needs no painting: forget it
d->dirtyItems->remove( (void *)i );
}
@@ -2896,7 +2896,7 @@ void TQListView::drawContentsOffset( TQPainter * p, int ox, int oy,
// need to paint current?
if ( ih > 0 && current->y < cy+ch && current->y+ih > cy ) {
if ( fx < 0 ) {
// tqfind first interesting column, once
x = 0;
c = 0;
cs = d->h->cellSize( 0 );
@@ -3125,7 +3125,7 @@ void TQListView::buildDrawableList() const
// down again if any tqchildren are not to be painted
if ( cur->y < d->topPixel )
d->topPixel = cur->y;
- // bottompixel is easy: the bottom item drawn tqcontains it
+ // bottompixel is easy: the bottom item drawn contains it
d->bottomPixel = cur->y + ih - 1;
}
@@ -3880,7 +3880,7 @@ bool TQListView::eventFilter( TQObject * o, TQEvent * e )
/*!
Returns a pointer to the list view containing this item.
- Note that this function traverses the items to the root to tqfind the
+ Note that this function traverses the items to the root to find the
listview. This function will return 0 for taken items - see
TQListViewItem::takeItem()
*/
@@ -3916,7 +3916,7 @@ int TQListViewItem::depth() const
that this item is visible, or can be made visible by scrolling).
This function might be relatively slow because of the tree
- traversions needed to tqfind the correct item.
+ traversions needed to find the correct item.
\sa itemBelow() TQListView::tqitemRect()
*/
@@ -4256,7 +4256,7 @@ void TQListView::contentsMousePressEventEx( TQMouseEvent * e )
d->ignoreEditAfterFocus = FALSE;
if ( currentItem() && currentItem()->renameBox &&
- !tqitemRect( currentItem() ).tqcontains( e->pos() ) ) {
+ !tqitemRect( currentItem() ).contains( e->pos() ) ) {
d->startEdit = FALSE;
if ( d->defRenameAction == Reject )
currentItem()->cancelRename( currentItem()->renameCol );
@@ -4557,7 +4557,7 @@ void TQListView::contentsMouseReleaseEventEx( TQMouseEvent * e )
if ( d->pressedColumn == 0 )
r.setLeft( r.left() + itemMargin() + ( currentItem()->depth() +
( rootIsDecorated() ? 1 : 0 ) ) * treeStepSize() - 1 );
- if ( r.tqcontains( e->pos() ) &&
+ if ( r.contains( e->pos() ) &&
!( e->state() & ( ShiftButton | ControlButton ) ) )
d->renameTimer->start( TQApplication::doubleClickInterval(), TRUE );
}
@@ -5179,7 +5179,7 @@ void TQListView::keyPressEvent( TQKeyEvent * e )
}
\endcode
- This might be interesting if you use this function to tqfind out
+ This might be interesting if you use this function to find out
where the user clicked and if you want to start a drag (which you
do not want to do if the user clicked onto the root decoration of
an item).
@@ -5948,7 +5948,7 @@ TQListViewItem * TQListView::firstChild() const
Returns the last item in the list view tree. Returns 0 if there
are no items in the TQListView.
- This function is slow because it traverses the entire tree to tqfind
+ This function is slow because it traverses the entire tree to find
the last item.
*/
@@ -5990,7 +5990,7 @@ void TQListView::repaintItem( const TQListViewItem * item ) const
d->dirtyItemTimer->start( 0, TRUE );
if ( !d->dirtyItems )
d->dirtyItems = new TQPtrDict<void>();
- d->dirtyItems->tqreplace( (void *)item, (void *)item );
+ d->dirtyItems->replace( (void *)item, (void *)item );
}
@@ -6426,7 +6426,7 @@ void TQCheckListItem::setCurrentState( ToggleState s )
void TQCheckListItem::setStoredState( ToggleState newState, void *key )
{
if ( myType == CheckBox || myType == CheckBoxController )
- d->statesDict->tqreplace( key, new ToggleState(newState) );
+ d->statesDict->replace( key, new ToggleState(newState) );
}
/*
@@ -6438,7 +6438,7 @@ TQCheckListItem::ToggleState TQCheckListItem::storedState( void *key ) const
if ( !d->statesDict )
return Off;
- ToggleState *foundState = d->statesDict->tqfind( key );
+ ToggleState *foundState = d->statesDict->find( key );
if ( foundState )
return ToggleState( *foundState );
else
@@ -6494,7 +6494,7 @@ void TQCheckListItem::activate()
TQRect r( x, y, boxsize-3, boxsize-3 );
// columns might have been swapped
r.moveBy( lv->header()->sectionPos( 0 ), 0 );
- if ( !r.tqcontains( pos ) )
+ if ( !r.contains( pos ) )
return;
}
if ( ( myType == CheckBox ) || ( myType == CheckBoxController) ) {
@@ -7444,7 +7444,7 @@ TQListViewItemIterator::TQListViewItemIterator()
}
/*!
- Constructs an iterator for the TQListView that tqcontains the \a
+ Constructs an iterator for the TQListView that contains the \a
item. The current iterator item is set to point to the \a item.
*/
@@ -7461,7 +7461,7 @@ TQListViewItemIterator::TQListViewItemIterator( TQListViewItem *item )
}
/*!
- Constructs an iterator for the TQListView that tqcontains the \a item
+ Constructs an iterator for the TQListView that contains the \a item
using the flags \a iteratorFlags. The current iterator item is set
to point to \a item or the next matching item if \a item doesn't
match the flags.
@@ -7772,7 +7772,7 @@ TQListViewItem *TQListViewItemIterator::current() const
TQListViewItemIteratorPrivate* TQListViewItemIterator::d() const
{
return qt_iteratorprivate_dict ?
- qt_iteratorprivate_dict->tqfind( (void *)this ) : 0;
+ qt_iteratorprivate_dict->find( (void *)this ) : 0;
}
void TQListViewItemIterator::init( int iteratorFlags )
@@ -8081,7 +8081,7 @@ bool TQListView::selectRange( TQListViewItem *newItem, TQListViewItem *oldItem,
The default comparison mode is case-sensitive, exact match.
*/
-TQListViewItem *TQListView::tqfindItem( const TQString& text, int column,
+TQListViewItem *TQListView::findItem( const TQString& text, int column,
TQt::ComparisonFlags compare ) const
{
if (text.isEmpty() && !(compare & TQt::ExactMatch))
@@ -8100,7 +8100,7 @@ TQListViewItem *TQListView::tqfindItem( const TQString& text, int column,
TQListViewItem *item;
TQListViewItem *beginsWithItem = 0;
TQListViewItem *endsWithItem = 0;
- TQListViewItem *tqcontainsItem = 0;
+ TQListViewItem *containsItem = 0;
for ( int pass = 0; pass < 2; pass++ ) {
while ( (item = it.current()) != sentinel ) {
@@ -8111,11 +8111,11 @@ TQListViewItem *TQListView::tqfindItem( const TQString& text, int column,
if ( compare & TQt::ExactMatch && itmtxt == comtxt )
return item;
if ( compare & TQt::BeginsWith && !beginsWithItem && itmtxt.startsWith( comtxt ) )
- beginsWithItem = tqcontainsItem = item;
+ beginsWithItem = containsItem = item;
if ( compare & TQt::EndsWith && !endsWithItem && itmtxt.endsWith( comtxt ) )
- endsWithItem = tqcontainsItem = item;
- if ( compare & TQt::Contains && !tqcontainsItem && itmtxt.tqcontains( comtxt ) )
- tqcontainsItem = item;
+ endsWithItem = containsItem = item;
+ if ( compare & TQt::Contains && !containsItem && itmtxt.contains( comtxt ) )
+ containsItem = item;
++it;
}
@@ -8128,8 +8128,8 @@ TQListViewItem *TQListView::tqfindItem( const TQString& text, int column,
return beginsWithItem;
else if ( endsWithItem )
return endsWithItem;
- else if ( tqcontainsItem )
- return tqcontainsItem;
+ else if ( containsItem )
+ return containsItem;
return 0;
}
@@ -2896,7 +2896,7 @@ void TQListView::drawContentsOffset( TQPainter * p, int ox, int oy,
if ( ih > 0 && current->y < cy+ch && current->y+ih > cy ) {
if ( fx < 0 ) {
- // tqfind first interesting column, once
+ // find first interesting column, once
x = 0;
c = 0;